@@ -74,12 +74,15 @@ def pickle_dump(obj, filename, protocol=None, *, fix_imports=True):
         pickle.dump(obj, f, protocol=protocol, fix_imports=fix_imports)
 
 
-def copyfile_if_not_exist(src, dst):
+def copyfile_if_not_exist(src, dst, quiet=False):
     if not os.path.exists(src):
-        print(f'| {src} does not exist.')
+        if not quiet:
+            print(f'| {src} does not exist.')
         return
     if os.path.exists(dst):
-        print(f'| {dst} already exists.')
+        if not quiet:
+            print(f'| {dst} already exists.')
         return
     shutil.copyfile(src, dst)
-    print(f'| Copy {src} to {dst}.')
+    if not quiet:
+        print(f'| Copy {src} to {dst}.')
